@@ -336,7 +336,9 @@ def get_watchlist(list_type=None, sort=None):
             from trakt.tv import TVEpisode
             show = d.pop('show')
             extract_ids(d['episode'])
-            results.append(TVEpisode(show.get('title', None), **d['episode']))
+            results.append(TVEpisode(show.get('title', None),
+                                     show_id=show.get('trakt', None),
+                                     **d['episode']))
         elif 'movie' in d:
             from trakt.movies import Movie
             results.append(Movie(**d.pop('movie')))
@@ -360,7 +362,7 @@ def get_watched(list_type=None, extended=None):
     if list_type and list_type not in valid_type:
         raise ValueError('list_type must be one of {}'.format(valid_type))
 
-    uri = 'sync/watchlist'
+    uri = 'sync/watched'
     if list_type:
         uri += '/{}'.format(list_type)
 
@@ -397,7 +399,7 @@ def get_collection(list_type=None, extended=None):
     if list_type and list_type not in valid_type:
         raise ValueError('list_type must be one of {}'.format(valid_type))
 
-    uri = 'sync/watchlist'
+    uri = 'sync/collection'
     if list_type:
         uri += '/{}'.format(list_type)
 
@@ -451,7 +453,7 @@ class Scrobbler(object):
         :param app_version: The media center application version
         :param app_date: The date that *app_version* was released
         """
-        super(Scrobbler, self).__init__()
+        super().__init__()
         self.progress, self.version = progress, app_version
         self.media, self.date = media, app_date
         if self.progress > 0:
@@ -459,15 +461,15 @@ class Scrobbler(object):
 
     def start(self):
         """Start scrobbling this :class:`Scrobbler`'s *media* object"""
-        self._post('scrobble/start')
+        return self._post('scrobble/start')
 
     def pause(self):
         """Pause the scrobbling of this :class:`Scrobbler`'s *media* object"""
-        self._post('scrobble/pause')
+        return self._post('scrobble/pause')
 
     def stop(self):
         """Stop the scrobbling of this :class:`Scrobbler`'s *media* object"""
-        self._post('scrobble/stop')
+        return self._post('scrobble/stop')
 
     def finish(self):
         """Complete the scrobbling this :class:`Scrobbler`'s *media* object"""
@@ -480,7 +482,7 @@ class Scrobbler(object):
         object
         """
         self.progress = progress
-        self.start()
+        return self.start()
 
     @post
     def _post(self, uri):
@@ -491,7 +493,8 @@ class Scrobbler(object):
         payload = dict(progress=self.progress, app_version=self.version,
                        date=self.date)
         payload.update(self.media.to_json_singular())
-        yield uri, payload
+        response = yield uri, payload
+        yield response
 
     def __enter__(self):
         """Context manager support for `with Scrobbler` syntax. Begins
