@@ -201,7 +201,7 @@ class TVShow(object):
     """A Class representing a TV Show object."""
 
     def __init__(self, title='', slug=None, **kwargs):
-        super(TVShow, self).__init__()
+        super().__init__()
         self.media_type = 'shows'
         self.top_watchers = self.top_episodes = self.year = self.tvdb = None
         self.imdb = self.genres = self.certification = self.network = None
@@ -227,8 +227,8 @@ class TVShow(object):
 
         return slugify(self.title + ' ' + str(self.year))
 
-    @classmethod
-    def search(cls, title, year=None):
+    @staticmethod
+    def search(title, year=None):
         """Perform a search for the specified *title*.
 
         :param title: The title to search for
@@ -439,7 +439,8 @@ class TVShow(object):
                 # Prepare episodes
                 episodes = []
                 for ep in season.pop('episodes', []):
-                    episode = TVEpisode(show=self.title, **ep)
+                    episode = TVEpisode(show=self.title,
+                                        show_id=self.trakt, **ep)
                     episodes.append(episode)
                 season['episodes'] = episodes
 
@@ -456,7 +457,8 @@ class TVShow(object):
         """
         if self._last_episode is None:
             data = yield self.ext + '/last_episode?extended=full'
-            self._last_episode = data and TVEpisode(show=self.title, **data)
+            self._last_episode = data and TVEpisode(show=self.title,
+                                                    show_id=self.trakt, **data)
         yield self._last_episode
 
     @property
@@ -467,7 +469,8 @@ class TVShow(object):
         """
         if self._next_episode is None:
             data = yield self.ext + '/next_episode?extended=full'
-            self._next_episode = data and TVEpisode(show=self.title, **data)
+            self._next_episode = data and TVEpisode(show=self.title,
+                                                    show_id=self.trakt, **data)
         yield self._next_episode
 
     @property
@@ -563,7 +566,7 @@ class TVSeason(object):
     """Container for TV Seasons"""
 
     def __init__(self, show, season=1, slug=None, **kwargs):
-        super(TVSeason, self).__init__()
+        super().__init__()
         self.show = show
         self.season = season
         self.slug = slug or slugify(show)
@@ -703,7 +706,7 @@ class TVEpisode(object):
     """Container for TV Episodes"""
 
     def __init__(self, show, season, number=-1, **kwargs):
-        super(TVEpisode, self).__init__()
+        super().__init__()
         self.media_type = 'episodes'
         self.show = show
         self.season = season
@@ -770,8 +773,8 @@ class TVEpisode(object):
         """Uri to retrieve additional image information"""
         return self.ext + '?extended=images'
 
-    @classmethod
-    def search(cls, title, year=None):
+    @staticmethod
+    def search(title, year=None):
         """Perform a search for an episode with a title matching *title*
 
         :param title: The title to search for
