@@ -70,12 +70,12 @@ class UserList(namedtuple('UserList', ['name', 'description', 'privacy',
     """A list created by a Trakt.tv :class:`User`"""
 
     def __init__(self, *args, **kwargs):
-        super(UserList, self).__init__()
+        super().__init__()
         self._items = list()
 
-    def __iter__(self, *args, **kwargs):
+    def __iter__(self):
         """Iterate over the items in this user list"""
-        return self._items.__iter__(*args, **kwargs)
+        return self._items.__iter__()
 
     @classmethod
     @post
@@ -97,7 +97,7 @@ class UserList(namedtuple('UserList', ['name', 'description', 'privacy',
             args['description'] = description
         data = yield 'users/{user}/lists'.format(user=slugify(creator)), args
         extract_ids(data)
-        yield UserList(creator=creator, user=creator, **data)
+        yield cls(creator=creator, user=creator, **data)
 
     @classmethod
     @get
@@ -109,7 +109,7 @@ class UserList(namedtuple('UserList', ['name', 'description', 'privacy',
         data = yield 'users/{user}/lists/{id}'.format(user=slugify(creator),
                                                       id=slugify(title))
         extract_ids(data)
-        ulist = UserList(creator=creator, **data)
+        ulist = cls(creator=creator, **data)
         ulist.get_items()
 
         yield ulist
@@ -147,7 +147,8 @@ class UserList(namedtuple('UserList', ['name', 'description', 'privacy',
                 show_data = item.pop('show')
                 extract_ids(show_data)
                 episode = TVEpisode(show_data['title'], item_data['season'],
-                                    item_data['number'])
+                                    item_data['number'],
+                                    show_id=show_data['trakt'])
                 self._items.append(episode)
             elif item_type == 'person':
                 self._items.append(Person(item_data['name'],
@@ -204,7 +205,7 @@ class UserList(namedtuple('UserList', ['name', 'description', 'privacy',
 class User(object):
     """A Trakt.tv User"""
     def __init__(self, username, **kwargs):
-        super(User, self).__init__()
+        super().__init__()
         self.username = username
         self._calendar = self._last_activity = self._watching = None
         self._movies = self._movie_collection = self._movies_watched = None
@@ -439,7 +440,8 @@ class User(object):
             ep_data = data.pop('episode')
             extract_ids(ep_data)
             sh_data = data.pop('show')
-            ep_data.update(data, show=sh_data.get('title'))
+            ep_data.update(data, show=sh_data.get('title'),
+                           show_id=sh_data.get('trakt'))
             yield TVEpisode(**ep_data)
 
     @staticmethod
